﻿CREATE TABLE IF NOT EXISTS "__EFMigrationsHistory" (
    "MigrationId" TEXT NOT NULL CONSTRAINT "PK___EFMigrationsHistory" PRIMARY KEY,
    "ProductVersion" TEXT NOT NULL
);

CREATE TABLE "ChatMessage" (
    "id" INTEGER NOT NULL CONSTRAINT "PK_ChatMessage" PRIMARY KEY AUTOINCREMENT,
    "messageId" INTEGER NULL,
    "createTimeStamp" INTEGER NOT NULL,
    "groupId" INTEGER NULL,
    "senderId" INTEGER NULL,
    "receiverId" INTEGER NULL,
    "bodyKindCode" INTEGER NULL,
    "unrecognizedBody" BLOB NULL,
    "stateCode" INTEGER NOT NULL,
    "setStateTimeStamp" INTEGER NULL,
    "errorMessage" TEXT NULL,
    "title" TEXT NULL,
    "content" TEXT NULL,
    "avatarUrl" TEXT NULL,
    "imageUrl" TEXT NULL,
    "imagePath" TEXT NULL,
    "imageWidth" INTEGER NULL,
    "imageHeight" INTEGER NULL,
    "voiceUrl" TEXT NULL,
    "voicePath" TEXT NULL,
    "voiceDuration" INTEGER NULL,
    "userId" INTEGER NULL,
    "iconUrl" TEXT NULL,
    "shareKindCode" INTEGER NULL,
    "shareUrl" TEXT NULL,
    "redPacketId" INTEGER NULL,
    "articleId" INTEGER NULL,
    "coverUrl" TEXT NULL,
    "articlePrice" INTEGER NULL,
    "articleCreateTimeStamp" INTEGER NULL,
    "articleLiveInfoUpdateTimeStamp" INTEGER NULL,
    "articleLiveInfoUpdateCount" INTEGER NULL,
    "removeMessageId" INTEGER NULL
);

CREATE TABLE "Group" (
    "id" INTEGER NOT NULL CONSTRAINT "PK_Group" PRIMARY KEY,
    "name" TEXT NULL,
    "avatar" TEXT NULL,
    "isAllowPrivateChat" INTEGER NULL,
    "isLocked" INTEGER NULL,
    "checksum" TEXT NULL,
    "membersChecksum" TEXT NULL,
    "quietTimeBegin" INTEGER NULL,
    "quietTimeLength" INTEGER NULL,
    "isStickyInLocal" INTEGER NULL,
    "isStickyInRemote" INTEGER NULL
);

CREATE TABLE "NoticeMessage" (
    "id" INTEGER NOT NULL CONSTRAINT "PK_NoticeMessage" PRIMARY KEY,
    "content" TEXT NOT NULL,
    "createTimeStamp" INTEGER NOT NULL
);

CREATE TABLE "OfficialMessage" (
    "id" INTEGER NOT NULL CONSTRAINT "PK_OfficialMessage" PRIMARY KEY,
    "content" TEXT NOT NULL,
    "createTimeStamp" INTEGER NOT NULL
);

CREATE TABLE "StationMessage" (
    "id" INTEGER NOT NULL CONSTRAINT "PK_StationMessage" PRIMARY KEY,
    "title" TEXT NOT NULL,
    "createTimeStamp" INTEGER NOT NULL
);

CREATE TABLE "SubscribeMessage" (
    "id" INTEGER NOT NULL CONSTRAINT "PK_SubscribeMessage" PRIMARY KEY,
    "content" TEXT NOT NULL,
    "typeName" TEXT NULL,
    "createTimeStamp" INTEGER NOT NULL,
    "articleId" INTEGER NULL,
    "groupId" INTEGER NULL,
    "groupName" TEXT NULL,
    "userId" INTEGER NULL,
    "userName" TEXT NULL,
    "userAvatar" TEXT NULL,
    "unreadCount" INTEGER NULL
);

CREATE TABLE "User" (
    "id" INTEGER NOT NULL CONSTRAINT "PK_User" PRIMARY KEY,
    "name" TEXT NULL,
    "alias" TEXT NULL,
    "avatar" TEXT NULL
);

CREATE TABLE "VerifyMessage" (
    "id" INTEGER NOT NULL CONSTRAINT "PK_VerifyMessage" PRIMARY KEY,
    "content" TEXT NOT NULL,
    "createTimeStamp" INTEGER NOT NULL,
    "httpMessageId" INTEGER NULL
);

CREATE TABLE "GroupChat" (
    "groupId" INTEGER NOT NULL CONSTRAINT "PK_GroupChat" PRIMARY KEY,
    "latestMessageId" INTEGER NULL,
    "lastReadMessageId" INTEGER NULL,
    "unreadNumber" INTEGER NULL,
    "latestAtMeMessageId" INTEGER NULL,
    "latestArticleMessageId" INTEGER NULL,
    "latestArticleTimeStamp" INTEGER NULL,
    "latestArticleOfViewTimeStamp" INTEGER NULL,
    CONSTRAINT "FK_GroupChat_Group_groupId" FOREIGN KEY ("groupId") REFERENCES "Group" ("id") ON DELETE CASCADE,
    CONSTRAINT "FK_GroupChat_ChatMessage_latestArticleMessageId" FOREIGN KEY ("latestArticleMessageId") REFERENCES "ChatMessage" ("id") ON DELETE RESTRICT,
    CONSTRAINT "FK_GroupChat_ChatMessage_latestAtMeMessageId" FOREIGN KEY ("latestAtMeMessageId") REFERENCES "ChatMessage" ("id") ON DELETE RESTRICT,
    CONSTRAINT "FK_GroupChat_ChatMessage_latestMessageId" FOREIGN KEY ("latestMessageId") REFERENCES "ChatMessage" ("id") ON DELETE RESTRICT
);

CREATE TABLE "StationMessageConfiguration" (
    "id" INTEGER NOT NULL CONSTRAINT "PK_StationMessageConfiguration" PRIMARY KEY AUTOINCREMENT,
    "latestMessageId" INTEGER NULL,
    "unReadAmount" INTEGER NULL,
    "latestReadMessageTimeStamp" INTEGER NULL,
    "isNeedUpdate" INTEGER NULL,
    CONSTRAINT "FK_StationMessageConfiguration_StationMessage_latestMessageId" FOREIGN KEY ("latestMessageId") REFERENCES "StationMessage" ("id") ON DELETE RESTRICT
);

CREATE TABLE "Member" (
    "id" INTEGER NOT NULL CONSTRAINT "PK_Member" PRIMARY KEY AUTOINCREMENT,
    "groupId" INTEGER NOT NULL,
    "userId" INTEGER NOT NULL,
    "roleCode" INTEGER NULL,
    "creditLine" INTEGER NULL,
    "isTop" INTEGER NULL,
    "latestChatTime" INTEGER NULL,
    "statusCode" INTEGER NULL,
    "endTimeOfForbid" INTEGER NULL,
    CONSTRAINT "FK_Member_User_userId" FOREIGN KEY ("userId") REFERENCES "User" ("id") ON DELETE CASCADE
);

CREATE TABLE "PrivateChat" (
    "userId" INTEGER NOT NULL CONSTRAINT "PK_PrivateChat" PRIMARY KEY,
    "latestMessageId" INTEGER NULL,
    "lastReadMessageId" INTEGER NULL,
    "unreadNumber" INTEGER NULL,
    "isShow" INTEGER NULL,
    CONSTRAINT "FK_PrivateChat_ChatMessage_latestMessageId" FOREIGN KEY ("latestMessageId") REFERENCES "ChatMessage" ("id") ON DELETE RESTRICT,
    CONSTRAINT "FK_PrivateChat_User_userId" FOREIGN KEY ("userId") REFERENCES "User" ("id") ON DELETE CASCADE
);

CREATE TABLE "Configuration" (
    "id" INTEGER NOT NULL CONSTRAINT "PK_Configuration" PRIMARY KEY AUTOINCREMENT,
    "noticesChecksum" TEXT NULL,
    "lastReadVerifyMessageId" INTEGER NULL,
    "latestVerifyMessageId" INTEGER NULL,
    "lastReadOfficialMessageId" INTEGER NULL,
    "latestOfficialMessageId" INTEGER NULL,
    "lastReadSubscribeMessageId" INTEGER NULL,
    "latestSubscribeMessageId" INTEGER NULL,
    "lastReadNoticeMessageId" INTEGER NULL,
    "latestNoticeMessageId" INTEGER NULL,
    "remoteReadFlagHashValue" INTEGER NULL,
    "localReadFlagHashValue" INTEGER NULL,
    CONSTRAINT "FK_Configuration_OfficialMessage_lastReadOfficialMessageId" FOREIGN KEY ("lastReadOfficialMessageId") REFERENCES "OfficialMessage" ("id") ON DELETE RESTRICT,
    CONSTRAINT "FK_Configuration_SubscribeMessage_lastReadSubscribeMessageId" FOREIGN KEY ("lastReadSubscribeMessageId") REFERENCES "SubscribeMessage" ("id") ON DELETE RESTRICT,
    CONSTRAINT "FK_Configuration_VerifyMessage_lastReadVerifyMessageId" FOREIGN KEY ("lastReadVerifyMessageId") REFERENCES "VerifyMessage" ("id") ON DELETE RESTRICT,
    CONSTRAINT "FK_Configuration_OfficialMessage_latestOfficialMessageId" FOREIGN KEY ("latestOfficialMessageId") REFERENCES "OfficialMessage" ("id") ON DELETE RESTRICT,
    CONSTRAINT "FK_Configuration_SubscribeMessage_latestSubscribeMessageId" FOREIGN KEY ("latestSubscribeMessageId") REFERENCES "SubscribeMessage" ("id") ON DELETE RESTRICT,
    CONSTRAINT "FK_Configuration_VerifyMessage_latestVerifyMessageId" FOREIGN KEY ("latestVerifyMessageId") REFERENCES "VerifyMessage" ("id") ON DELETE RESTRICT
);

CREATE INDEX "IX_Configuration_lastReadOfficialMessageId" ON "Configuration" ("lastReadOfficialMessageId");

CREATE INDEX "IX_Configuration_lastReadSubscribeMessageId" ON "Configuration" ("lastReadSubscribeMessageId");

CREATE INDEX "IX_Configuration_lastReadVerifyMessageId" ON "Configuration" ("lastReadVerifyMessageId");

CREATE INDEX "IX_Configuration_latestOfficialMessageId" ON "Configuration" ("latestOfficialMessageId");

CREATE INDEX "IX_Configuration_latestSubscribeMessageId" ON "Configuration" ("latestSubscribeMessageId");

CREATE INDEX "IX_Configuration_latestVerifyMessageId" ON "Configuration" ("latestVerifyMessageId");

CREATE INDEX "IX_GroupChat_latestArticleMessageId" ON "GroupChat" ("latestArticleMessageId");

CREATE INDEX "IX_GroupChat_latestAtMeMessageId" ON "GroupChat" ("latestAtMeMessageId");

CREATE INDEX "IX_GroupChat_latestMessageId" ON "GroupChat" ("latestMessageId");

CREATE INDEX "IX_Member_userId" ON "Member" ("userId");

CREATE INDEX "IX_PrivateChat_latestMessageId" ON "PrivateChat" ("latestMessageId");

CREATE INDEX "IX_StationMessageConfiguration_latestMessageId" ON "StationMessageConfiguration" ("latestMessageId");

INSERT INTO "__EFMigrationsHistory" ("MigrationId", "ProductVersion")
VALUES ('20200829101104_InitialCreate', '3.1.7');